@@ -56,7 +56,7 @@ $copyright = '';
 $editor = '';
 $ttl = 0;
 $image = '';
-$template = file_get_contents(dirname(__FILE__).'/templates/orig_feed_template.tpl');
+$template = file_get_contents(__DIR__.'/templates/orig_feed_template.tpl');
 $error = '';
 $categories = array();
 
@@ -140,7 +140,7 @@ if( isset($params['cancel']) )
 }
 else if( isset($params['resettemplate']) )
 {
-  $template = file_get_contents(dirname(__FILE__).'/templates/orig_feed_template.tpl');
+  $template = file_get_contents(__DIR__.'/templates/orig_feed_template.tpl');
 }
 else if( isset($params['submit']) )
 {
@@ -306,10 +306,10 @@ $smarty->assign('endtabheader',$this->EndTabHeaders());
 
 $smarty->assign('starttabcontent',$this->StartTabContent());
 $smarty->assign('starttab_details',$this->StartTab('details',$params));
-$smarty->assign('tab_details',include(dirname(__FILE__).'/function.admin_addfeed_details.php'));
+$smarty->assign('tab_details',include(__DIR__.'/function.admin_addfeed_details.php'));
 $smarty->assign('endtab',$this->EndTab());
 $smarty->assign('starttab_template',$this->StartTab('template',$params));
-$smarty->assign('tab_template',include(dirname(__FILE__).'/function.admin_addfeed_template.php'));
+$smarty->assign('tab_template',include(__DIR__.'/function.admin_addfeed_template.php'));
 $smarty->assign('endtabcontent',$this->EndTabContent());
 
 
